<div align="center">

# Crazy Thursday

<!-- prettier-ignore-start -->
<!-- markdownlint-disable-next-line MD036 -->
_🍗 天天疯狂 🍗_
<!-- prettier-ignore-end -->

</div>

<p align="center">
  
  <a href="https://github.com/KafCoppelia/nonebot_plugin_crazy_thursday/blob/main/LICENSE">
    <img src="https://img.shields.io/badge/license-MIT-informational">
  </a>
  
  <a href="https://github.com/nonebot/nonebot2">
    <img src="https://img.shields.io/badge/nonebot2-2.0.0alpha.16-green">
  </a>
  
  <a href="">
    <img src="https://img.shields.io/badge/release-v0.1.5-orange">
  </a>
  
</p>
</p>

## 版本

v0.1.5

⚠ 适配nonebot2-2.0.0alpha.16，适配beta.1版本将会放在dev分支。

## 安装

1. 通过`pip`或`nb`安装；

2. 读取文案的默认路径位于`./resource`下；

## 功能

天天疯狂！随机输出KFC疯狂星期四文案。

## 命令

1. 天天疯狂，疯狂星期[一|二|三|四|五|六|日]；
2. 输入**疯狂星期八**等不合法时间将提示；

## 本插件改自HoshinoBot疯狂星期四插件

[HoshinoBot-fucking_crazy_thursday](https://github.com/Nicr0n/fucking_crazy_thursday)